@@ -45,9 +45,10 @@ class CameraPub(object):
     def publish(self, topic='robot_mono', flip=2):
         while self.cap.isOpened():
             ret_val, img = self.cap.read()
-            timestamp = time.time()
-            pdata = packImage(img, timestamp)
-            self.pub.send(topic, pdata)
+            if img is not None:
+                timestamp = time.time()
+                pdata = packImage(img, timestamp)
+                self.pub.send(topic, pdata)
         self.cap.release()
 
 
@@ -66,9 +67,9 @@ class CameraSub(object):
     def subscribe(self, topic='robot_mono', callback=None):
         self.sub.recv(topic, callback or self.process)
 
-    def process(self, pdata, *arg):
+    def process(self, pdata, *arg):        
         if 1 == pdata:
-            logging.debug('not a stable connection, pass that message')
+            logging.debug('heart beat...')
         else:
             img, _ = unpackImage(pdata)
             # do what you want in your own process
