@@ -23,11 +23,13 @@ class Subscriber(object):
                  port='6379',
                  db=3,
                  health_check_interval=1):
-        self.item = None
+        self.item = None        
         self.name = name
         self.host, self.port = host, port
         self.db, self.health_check_interval = db, health_check_interval
         self.pool = redis.ConnectionPool(host=host, port=port, db=self.db)
+        self.listen = {}
+        self.recved = {}        
         logging.debug('create a redis pool at {}:{} for subscriber {}'.format(
             host, port, name))
 
@@ -38,6 +40,12 @@ class Subscriber(object):
     #                 Subscriber._instance = object.__new__(cls)
     #     return Subscriber._instance
 
+    def start_listen(self, topic, callback=None):
+        t = threading.Thread(target=self.pop_listen, args=(topic, callback))
+        t.start()
+        logging.info('start a new thread {}'.format(topic))
+        self.listen[topic] = t
+
     def get_connection(self):
         return redis.StrictRedis(connection_pool=self.pool,
                                  db=self.db,
@@ -45,16 +53,18 @@ class Subscriber(object):
                                  retry_on_timeout=True,
                                  socket_timeout=4)
 
-    def pop_listen(self, topic, callback):
+    def pop_listen(self, topic, callback):        
         while True:
-            item, name = self.item, self.name
-            if callback and item and item['channel'] == topic.encode():
-                callback(item['data'], name, topic, time.time())
+            if topic in self.recved and self.recved[topic]:
+                item, name = self.item, self.name
+                self.recved[topic] = False
+                if callback and item and item['channel'] == topic.encode():
+                    callback(item['data'], name, topic, time.time())
 
     def recv(self, topic, callback=None):
         # global gitem
-        t = threading.Thread(target=self.pop_listen, args=(topic, callback))
-        t.start()
+        if topic not in self.listen:
+            self.start_listen(topic, callback)
         # rc = Subscriber._instance.get_connection()
         # name = Subscriber._instance.name
         rc = self.get_connection()
@@ -65,8 +75,9 @@ class Subscriber(object):
             if callback:
                 for item in ps.listen():
                     self.item = item
+                    self.recved[topic] = True
                     # if callback:
-                    #     callback(item['data'], name, topic, time.time())                    
+                    #     callback(item['data'], name, topic, time.time())
                     logging.debug(
                         'Redis server {}\'s top {} subscribe a data at {}.'.format(
                             name, topic, time.time()))
